{% extends "aasrp/base.html" %}

{% load i18n %}

{% block page_title %}
    {% translate "Add/Edit After Action Report Link" %}
{% endblock %}

{% block aasrp_body %}
    {% include "aasrp/partials/link-edit/form.html" %}
{% endblock %}

{% block extra_css %}
    {% include "aasrp/bundles/aa-srp-css.html" %}
    {% include "aasrp/bundles/aa-srp-form-css.html" %}
{% endblock %}
