# Generated by Django 3.2.2 on 2021-05-12 02:02

# Django
import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("aasrp", "0004_aasrpusersettings"),
    ]

    operations = [
        migrations.CreateModel(
            name="AaSrpInsurance",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("insurance_level", models.CharField(default="", max_length=254)),
                ("insurance_cost", models.FloatField()),
                ("insurance_payout", models.FloatField()),
                (
                    "srp_request",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="insurance",
                        to="aasrp.aasrprequest",
                    ),
                ),
            ],
            options={
                "verbose_name": "Ship Insurance",
                "verbose_name_plural": "Ship Insurances",
                "default_permissions": (),
            },
        ),
    ]
