# Generated by Django 3.1.5 on 2021-01-06 12:27

# Django
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("aasrp", "0002_relations_update"),
    ]

    operations = [
        migrations.AddField(
            model_name="aasrprequest",
            name="reject_info",
            field=models.TextField(blank=True, default=""),
        ),
    ]
