{% load i18n %}

{% if perms.aasrp.manage_srp %}
    <li class="nav-item">
        <a href="{% url 'aasrp:all' %}" class="nav-link py-0">
            <span class="btn btn-secondary">{% translate "View all" %}</span>
        </a>
    </li>
{% endif %}

{% if perms.aasrp.create_srp or perms.aasrp.manage_srp %}
    <li class="nav-item">
        <a href="{% url 'aasrp:add_srp_link' %}" class="nav-link py-0">
            <span class="btn btn-success">{% translate "Add SRP link" %}</span>
        </a>
    </li>
{% endif %}
