{% load i18n %}

<li class="nav-item" role="presentation">
    <a
        class="nav-link active"
        id="srp-links"
        data-bs-toggle="tab"
        href="#tab-srp-links"
        role="tab"
        aria-controls="tab-srp-links"
        aria-selected="true"
    >
        {% translate "SRP links" %}
    </a>
</li>

<li class="nav-item" role="presentation">
    <a
        class="nav-link"
        id="user-srp-requests"
        data-bs-toggle="tab"
        href="#tab-user-srp-requests"
        role="tab"
        aria-controls="tab-user-srp-requests"
        aria-selected="true"
    >
        {% translate "Your SRP requests" %}
    </a>
</li>

<li class="nav-item" role="presentation">
    <a
        class="nav-link"
        id="user-settings"
        data-bs-toggle="tab"
        href="#tab-user-settings"
        role="tab"
        aria-controls="tab-user-settings"
        aria-selected="true"
    >
        {% translate "Settings" %}
    </a>
</li>
