{% load i18n %}

<!-- own srp requests tab -->
<div class="tab-pane fade" id="{{ tab_name }}" role="tabpanel" aria-labelledby="tab-srp-links">
    <div class="alert alert-info" role="alert">
        <div class="text-end srp-dashboard-user-isk-cost">
            {% translate "Your total SRP cost" %}:
            <span class="srp-dashboard-user-isk-cost-amount"></span>
        </div>
    </div>

    <div class="table-responsive">
        <table class="table table-striped table-aasrp table-srp-requests w-100" id="table_{{ tab_name }}">
            <thead>
                <tr>
                    <th class="w-auto">{% translate "Request time" %}</th>
                    <th class="w-auto">{% translate "Character" %}</th>
                    <th class="w-auto">{% translate "Request details" %}</th>
                    <th class="w-auto">{% translate "Ship" %}</th>
                    <th class="w-auto">{% translate "ISK lost" %}</th>
                    <th class="w-auto">{% translate "SRP payout" %}</th>
                    <th class="w-auto"><!-- {% translate "Status" %} --></th>
                </tr>
            </thead>

            <tbody></tbody>
        </table>
    </div>
</div>
